@@ -57,6 +57,11 @@ class CreateAggregateCompliancePackRequest(RpcRequest):
 
 	def set_AggregatorId(self, AggregatorId):  # String
 		self.add_body_params('AggregatorId', AggregatorId)
+	def get_DefaultEnable(self): # Boolean
+		return self.get_body_params().get('DefaultEnable')
+
+	def set_DefaultEnable(self, DefaultEnable):  # Boolean
+		self.add_body_params('DefaultEnable', DefaultEnable)
 	def get_ConfigRules(self): # Array
 		return self.get_body_params().get('ConfigRules')
 
